@@ -13,8 +13,8 @@ class Worker(threading.Thread):
         self.context = context
 
     def run(self):
-        r = self.resource(channel=self.channel,
-                          logger=self.logger,
+        r = self.resource(logger=self.logger,
+                          channel=self.channel,
                           context=self.context)
 
         # joblog start message
